@@ -39,7 +39,8 @@ def dnastack():
 dnastack.add_command(dataconnect_commands.dataconnect)
 dnastack.add_command(config_commands.config)
 dnastack.add_command(file_commands.files)
-dnastack.add_command(auth_commands.auth)
+# dnastack.add_command(auth_commands.auth)
+dnastack.add_command(collections_commands.collections)
 
 if __name__ == "__main__":
-    dnastack()
+    dnastack.main(prog_name="dnastack")
