@@ -29,13 +29,13 @@ def cli_login(ctx, refresh=False):
             email,
             personal_access_token,
             auth_params=auth_params,
-            search_url=get_config(ctx, "search-url"),
+            dataconnect_url=get_config(ctx, "data-connect-url"),
             drs_url=re.search(
                 r"(?<=https://)([^/])+(?=/.*)", get_config(ctx, "drs-url")
             ).group(0),
         )
     except:
-        # click.secho(f"There was an error generating an access token", fg="red")
+        click.secho(f"There was an error generating an access token", fg="red")
         sys.exit(1)
 
     # convert the expiry from a relative time to an actual timestamp
