@@ -34,8 +34,9 @@ def query(
     else:
         output = io.StringIO()
         writer = csv.writer(output)
-        for res in handle_client_results(results, search_url):
-            data_row = map(lambda x: str(x).replace(",", "\,"), res.values())
+        for res in handle_client_results(results, dataconnect_url):
+            data_row = list(map(lambda x: str(x).replace(",", "\,"), res.values()))
+
             writer.writerow(data_row)
         output = output.getvalue()
 
@@ -48,7 +49,7 @@ def query(
         return output
 
 
-def get_tables(dataconnect_url, oauth_token: Optional[str] = None):
+def list_tables(dataconnect_url, oauth_token: Optional[str] = None):
     dataconnect_client = get_dataconnect_client(dataconnect_url, oauth_token)
 
     try:
