@@ -50,12 +50,21 @@ def is_drs_url(url):
 def get_object_info_url_from_drs(url):
     drs_host = re.search(r"(?<=drs://)([^/])+(?=/.*)", url)
     if not drs_host:
-        click.secho(f"Could not get drs object id from url {url}\n", fg="red")
-        raise Exception(f"Could not get drs object id from url {url}")
+        click.secho(f"Could not get drs host from url {url}\n", fg="red")
+        raise Exception(f"Could not get drs host from url {url}")
     object_url = f"https://{drs_host.group(0)}/ga4gh/drs/v1/"
     return object_url, drs_host
 
 
+def get_object_id_from_drs(url):
+    object_id = re.search(r"(?<=/)(\w{8}-\w{4}-\w{4}-\w{4}-\w{12})", url)
+    if object_id:
+        return object_id.group(0)
+    else:
+        click.secho(f"Could not get drs object id from url {url}\n", fg="red")
+        raise Exception(f"Could not get drs object id from url {url}")
+
+
 def download_file(
     url,
     output_dir,
@@ -77,7 +86,7 @@ def download_file(
         try:
             drs_server, drs_host = get_object_info_url_from_drs(url)
             drs_client = get_drs_client(drs_server)
-            object_id = url.split("/")[-1]
+            object_id = get_object_id_from_drs(url)
             object_info = drs_client.get_object_info(object_id)
         except HTTPError as e:
             if e.response.status_code == 401:
