@@ -10,7 +10,7 @@ auth_params = {
 
 cli_directory = f"{os.path.expanduser('~')}/.dnastack"
 config_file_path = f"{cli_directory}/config.yaml"
-downloads_directory = f"{cli_directory}/downloads"
+downloads_directory = f"{os.getcwd()}"
 
 ACCEPTED_CONFIG_KEYS = [
     "data-connect-url",
@@ -22,6 +22,7 @@ ACCEPTED_CONFIG_KEYS = [
     "client-id",
     "client-secret",
     "client-redirect-uri",
+    "collections-url",
 ]
 
 auth_scopes = "openid drs-object:write drs-object:access dataconnect:info dataconnect:data dataconnect:query"
